@@ -8,7 +8,7 @@ async fn main() {
     let target = Language::English;
     let input = "Le texte français.";
 
-    let data = translate(source, target, input).await.unwrap();
+    let data = translate(source, target, input, None).await.unwrap();
 
     println!("Input {}: {}", data.source.as_pretty(), data.input);
     println!("Output {}: {}", data.target.as_pretty(), data.output);
